Name:           beignet
Version:        1.0.3
Release:        3%{?dist}
Summary:        Open source implementation of the OpenCL for Intel GPUs

License:        LGPLv2+
URL:            https://01.org/beignet/
Source0:        https://01.org/sites/default/files/%{name}-%{version}-source.tar.gz

BuildRequires:  cmake
BuildRequires:  llvm-devel >= 3.3 clang-devel >= 3.3 llvm-static >= 3.3
BuildRequires:  libdrm-devel mesa-libGL-devel mesa-libEGL-devel mesa-libgbm-devel ocl-icd-devel
BuildRequires:  zlib-devel libedit-devel
BuildRequires:  opencl-headers
BuildRequires:  git

%if 0%{?fedora} > 22
BuildRequires:  python3-devel
%else
BuildRequires:  python2-devel
%endif

Requires:       opencl-filesystem

Patch0: 0001-Remove-some-LGPL-incompatible-code.patch
Patch1: 0002-GBE-Fix-the-immediate-data-type.patch
Patch2: 0003-correct-the-src-output-of-alu3-when-OCL_OUTPUT_ASM-1.patch
Patch3: 0004-Add-a-sanity-test-in-clGetDeviceIDs.patch
Patch4: 0005-Docs-update-clarify-Haswell-issues.patch
Patch5: 0006-utest_pow-don-t-fail-on-declared-lack-of-denormals.patch
Patch6: 0007-Make-tgamma-meet-the-accuracy-standard.patch
Patch7: 0008-Allow-building-with-Python-3.patch
Patch8: 0009-utests-fix-test-case-builtin_tgamma.patch

ExclusiveArch:  x86_64 %{ix86}

%description
Beignet is an open source implementation of the OpenCL specification - a generic
compute oriented API. This code base contains the code to run OpenCL programs
on Intel GPUs which basically defines and implements the OpenCL host functions
required to initialize the device, create the command queues, the kernels and
the programs and run them on the GPU. 

%package devel
Summary:        Open source implementation of the OpenCL for Intel GPUs devel package
Requires:       opencl-headers
Requires:       beignet%{?_isa} = %{version}-%{release}

%description devel
Devel package for Beignet is an open source implementation of the OpenCL
specification - a generic compute oriented API.

%prep
%autosetup -n Beignet-%{version}-Source -S git
mkdir build

%build
pushd build
  %cmake ../ -DLLVM_INSTALL_DIR=%{_bindir}/
  %make_build
popd

%install
pushd build
  %make_install
popd
find %{buildroot}%{_includedir}/CL/ -not -name "cl_intel.h" -type f -delete

%files
%license COPYING
%doc README.md
%{_libdir}/beignet/
%{_sysconfdir}/OpenCL/vendors/intel-beignet.icd

%files devel
%doc docs/*
%{_includedir}/CL/cl_intel.h

%changelog
* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.0.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Tue May 19 2015 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 1.0.3-2
- Fix licensing issues with not compatipble LGPL code
- use python3-devel for fedora23+
- use license macro
- use make_build macro

* Fri May 08 2015 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 1.0.3-1
- Update to 1.0.3 (RHBZ #1202329)

* Mon Jan 19 2015 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 1.0.1-1
- 1.0.1 (RHBZ #1183497)

* Mon Nov 17 2014 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 1.0.0-1
- 1.0.0 (RHBZ #1142892)

* Fri Aug 15 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.9.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Mon Jul 28 2014 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.9.2-1
- 0.9.2 upstream release (RHBZ #1123941)

* Sun Jul 06 2014 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.9.1-1
- 0.9.1 upstream release (RHBZ #1116622)

* Fri Jul 04 2014 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.9.0-1
- Update ot 0.9.0

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Feb 13 2014 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.8-2
- Update LLVM/Terminfo patch from upstream maillist

* Wed Feb 12 2014 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.8-1
- 0.8 upstream release

* Mon Jan 20 2014 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.3-9.48f8e5b
- We need opencl-filesystem as requires

* Thu Jan 16 2014 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.3-8.48f8e5b
- Latest master branch

* Wed Jan 15 2014 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.3-7.984d680
- Fix libdir

* Wed Jan 15 2014 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.3-6.984d680
- Update to latest master + apply patches from upstream list

* Tue Jan 14 2014 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.3-5.e427b3e
- spec: trivial fix

* Mon Jan 13 2014 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.3-4.e427b3e
- Build only on x86 arches, because only Intel GPUs supported here
- Fix license
- Update description

* Mon Jan 13 2014 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.3-3.e427b3e
- Update to latest master

* Fri Jan 10 2014 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.3-2.991e0d7
- Git from OpenCL-1.2 branch

* Fri Jan 10 2014 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 0.3-1
- Initial package
